# aptos_api_dart
The Aptos Node API is a RESTful API for client applications to interact with the Aptos blockchain.


This Dart package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.2
- Build package: org.openapitools.codegen.languages.DartDioClientCodegen
For more information, please visit [https://github.com/aptos-labs/aptos-core](https://github.com/aptos-labs/aptos-core)

## Requirements

* Dart 2.12.0 or later OR Flutter 1.26.0 or later
* Dio 4.0.0+

## Installation & Usage

### pub.dev
To use the package from [pub.dev](https://pub.dev), please include the following in pubspec.yaml
```yaml
dependencies:
  aptos_api_dart: 0.0.1
```

### Github
If this Dart package is published to Github, please include the following in pubspec.yaml
```yaml
dependencies:
  aptos_api_dart:
    git:
      url: https://github.com/GIT_USER_ID/GIT_REPO_ID.git
      #ref: main
```

### Local development
To use the package from your local drive, please include the following in pubspec.yaml
```yaml
dependencies:
  aptos_api_dart:
    path: /path/to/aptos_api_dart
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```dart
import 'package:aptos_api_dart/aptos_api_dart.dart';


final api = AptosApiDart().getAccountsApi();
final String address = address_example; // String | 

try {
    final response = await api.getAccount(address);
    print(response);
} catch on DioError (e) {
    print("Exception when calling AccountsApi->getAccount: $e\n");
}

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
[*AccountsApi*](doc/AccountsApi.md) | [**getAccount**](doc/AccountsApi.md#getaccount) | **GET** /accounts/{address} | Get account
[*AccountsApi*](doc/AccountsApi.md) | [**getAccountModule**](doc/AccountsApi.md#getaccountmodule) | **GET** /accounts/{address}/module/{module_name} | Get module by module id.
[*AccountsApi*](doc/AccountsApi.md) | [**getAccountModules**](doc/AccountsApi.md#getaccountmodules) | **GET** /accounts/{address}/modules | Get account modules
[*AccountsApi*](doc/AccountsApi.md) | [**getAccountResource**](doc/AccountsApi.md#getaccountresource) | **GET** /accounts/{address}/resource/{resource_type} | Get resource by account address and resource type.
[*AccountsApi*](doc/AccountsApi.md) | [**getAccountResources**](doc/AccountsApi.md#getaccountresources) | **GET** /accounts/{address}/resources | Get account resources
[*EventsApi*](doc/EventsApi.md) | [**getEventsByEventHandle**](doc/EventsApi.md#geteventsbyeventhandle) | **GET** /accounts/{address}/events/{event_handle_struct}/{field_name} | Get events by event handle
[*EventsApi*](doc/EventsApi.md) | [**getEventsByEventKey**](doc/EventsApi.md#geteventsbyeventkey) | **GET** /events/{event_key} | Get events by event key
[*GeneralApi*](doc/GeneralApi.md) | [**getLedgerInfo**](doc/GeneralApi.md#getledgerinfo) | **GET** / | Ledger information
[*GeneralApi*](doc/GeneralApi.md) | [**getSpecHtml**](doc/GeneralApi.md#getspechtml) | **GET** /spec.html | API document
[*GeneralApi*](doc/GeneralApi.md) | [**getSpecYaml**](doc/GeneralApi.md#getspecyaml) | **GET** /openapi.yaml | OpenAPI specification
[*StateApi*](doc/StateApi.md) | [**getAccount**](doc/StateApi.md#getaccount) | **GET** /accounts/{address} | Get account
[*StateApi*](doc/StateApi.md) | [**getAccountModule**](doc/StateApi.md#getaccountmodule) | **GET** /accounts/{address}/module/{module_name} | Get module by module id.
[*StateApi*](doc/StateApi.md) | [**getAccountModules**](doc/StateApi.md#getaccountmodules) | **GET** /accounts/{address}/modules | Get account modules
[*StateApi*](doc/StateApi.md) | [**getAccountResource**](doc/StateApi.md#getaccountresource) | **GET** /accounts/{address}/resource/{resource_type} | Get resource by account address and resource type.
[*StateApi*](doc/StateApi.md) | [**getAccountResources**](doc/StateApi.md#getaccountresources) | **GET** /accounts/{address}/resources | Get account resources
[*StateApi*](doc/StateApi.md) | [**getTableItem**](doc/StateApi.md#gettableitem) | **POST** /tables/{table_handle}/item | Get table item by handle and key.
[*TableApi*](doc/TableApi.md) | [**getTableItem**](doc/TableApi.md#gettableitem) | **POST** /tables/{table_handle}/item | Get table item by handle and key.
[*TransactionsApi*](doc/TransactionsApi.md) | [**createSigningMessage**](doc/TransactionsApi.md#createsigningmessage) | **POST** /transactions/signing_message | Create transaction signing message
[*TransactionsApi*](doc/TransactionsApi.md) | [**getAccountTransactions**](doc/TransactionsApi.md#getaccounttransactions) | **GET** /accounts/{address}/transactions | Get account transactions
[*TransactionsApi*](doc/TransactionsApi.md) | [**getTransaction**](doc/TransactionsApi.md#gettransaction) | **GET** /transactions/{txn_hash_or_version} | Get transaction
[*TransactionsApi*](doc/TransactionsApi.md) | [**getTransactions**](doc/TransactionsApi.md#gettransactions) | **GET** /transactions | Get transactions
[*TransactionsApi*](doc/TransactionsApi.md) | [**simulateTransaction**](doc/TransactionsApi.md#simulatetransaction) | **POST** /transactions/simulate | Simulate transaction
[*TransactionsApi*](doc/TransactionsApi.md) | [**submitTransaction**](doc/TransactionsApi.md#submittransaction) | **POST** /transactions | Submit transaction


## Documentation For Models

 - [Account](doc/Account.md)
 - [AccountResource](doc/AccountResource.md)
 - [AccountSignature](doc/AccountSignature.md)
 - [AptosError](doc/AptosError.md)
 - [BlockMetadataTransaction](doc/BlockMetadataTransaction.md)
 - [BlockMetadataTransactionAllOf](doc/BlockMetadataTransactionAllOf.md)
 - [CreateSigningMessage200Response](doc/CreateSigningMessage200Response.md)
 - [DeleteModule](doc/DeleteModule.md)
 - [DeleteResource](doc/DeleteResource.md)
 - [DeleteTableItem](doc/DeleteTableItem.md)
 - [DirectWriteSet](doc/DirectWriteSet.md)
 - [Ed25519Signature](doc/Ed25519Signature.md)
 - [Event](doc/Event.md)
 - [GenesisTransaction](doc/GenesisTransaction.md)
 - [GenesisTransactionAllOf](doc/GenesisTransactionAllOf.md)
 - [GetAccount404Response](doc/GetAccount404Response.md)
 - [GetLedgerInfo400Response](doc/GetLedgerInfo400Response.md)
 - [GetLedgerInfo500Response](doc/GetLedgerInfo500Response.md)
 - [LedgerInfo](doc/LedgerInfo.md)
 - [ModuleBundlePayload](doc/ModuleBundlePayload.md)
 - [MoveAbility](doc/MoveAbility.md)
 - [MoveFunction](doc/MoveFunction.md)
 - [MoveFunctionGenericTypeParamsInner](doc/MoveFunctionGenericTypeParamsInner.md)
 - [MoveModule](doc/MoveModule.md)
 - [MoveModuleABI](doc/MoveModuleABI.md)
 - [MoveScript](doc/MoveScript.md)
 - [MoveStruct](doc/MoveStruct.md)
 - [MoveStructField](doc/MoveStructField.md)
 - [MoveStructGenericTypeParamsInner](doc/MoveStructGenericTypeParamsInner.md)
 - [MultiAgentSignature](doc/MultiAgentSignature.md)
 - [MultiEd25519Signature](doc/MultiEd25519Signature.md)
 - [OnChainTransaction](doc/OnChainTransaction.md)
 - [OnChainTransactionInfo](doc/OnChainTransactionInfo.md)
 - [PendingTransaction](doc/PendingTransaction.md)
 - [PendingTransactionAllOf](doc/PendingTransactionAllOf.md)
 - [Script](doc/Script.md)
 - [ScriptFunctionPayload](doc/ScriptFunctionPayload.md)
 - [ScriptPayload](doc/ScriptPayload.md)
 - [ScriptWriteSet](doc/ScriptWriteSet.md)
 - [StateCheckpointTransaction](doc/StateCheckpointTransaction.md)
 - [StateCheckpointTransactionAllOf](doc/StateCheckpointTransactionAllOf.md)
 - [SubmitTransaction413Response](doc/SubmitTransaction413Response.md)
 - [SubmitTransaction415Response](doc/SubmitTransaction415Response.md)
 - [SubmitTransactionRequest](doc/SubmitTransactionRequest.md)
 - [TableItemDeletion](doc/TableItemDeletion.md)
 - [TableItemRequest](doc/TableItemRequest.md)
 - [Token](doc/Token.md)
 - [TokenData](doc/TokenData.md)
 - [TokenId](doc/TokenId.md)
 - [Transaction](doc/Transaction.md)
 - [TransactionPayload](doc/TransactionPayload.md)
 - [TransactionSignature](doc/TransactionSignature.md)
 - [UserCreateSigningMessageRequest](doc/UserCreateSigningMessageRequest.md)
 - [UserCreateSigningMessageRequestAllOf](doc/UserCreateSigningMessageRequestAllOf.md)
 - [UserTransaction](doc/UserTransaction.md)
 - [UserTransactionAllOf](doc/UserTransactionAllOf.md)
 - [UserTransactionRequest](doc/UserTransactionRequest.md)
 - [UserTransactionSignature](doc/UserTransactionSignature.md)
 - [WriteModule](doc/WriteModule.md)
 - [WriteResource](doc/WriteResource.md)
 - [WriteSet](doc/WriteSet.md)
 - [WriteSetChange](doc/WriteSetChange.md)
 - [WriteSetPayload](doc/WriteSetPayload.md)
 - [WriteTableItem](doc/WriteTableItem.md)


## Documentation For Authorization

 All endpoints do not require authorization.


## Author



